@@ -123,7 +123,7 @@ class SentenceTransformer(nn.Sequential):
         else:
             sentences_tokenized = [self.tokenize(sen) for sen in sentences]
 
-        length_sorted_idx = np.argsort([len(sentences_tokenized) for sen in sentences])
+        length_sorted_idx = np.argsort([len(sen) for sen in sentences])
 
         iterator = range(0, len(sentences), batch_size)
         if show_progress_bar:
@@ -165,7 +165,7 @@ class SentenceTransformer(nn.Sequential):
                     embeddings = embeddings * input_mask_expanded
 
                 if convert_to_numpy:
-                    embeddings = embeddings.cpu().detach().numpy()
+                    embeddings = np.copy(embeddings.cpu().detach().numpy())
 
                 all_embeddings.extend(embeddings)
 
