@@ -4,7 +4,7 @@ from typing import Tuple, List
 from tqdm import tqdm
 import sys
 import importlib
-
+import os
 
 def batch_to_device(batch, target_device: device):
     """
@@ -25,12 +25,14 @@ def batch_to_device(batch, target_device: device):
 
 
 def http_get(url, path):
-    with open(path, "wb") as file_binary:
-        req = requests.get(url, stream=True)
-        if req.status_code != 200:
-            print("Exception when trying to download {}. Response {}".format(url, req.status_code), file=sys.stderr)
-            req.raise_for_status()
+    req = requests.get(url, stream=True)
+    if req.status_code != 200:
+        print("Exception when trying to download {}. Response {}".format(url, req.status_code), file=sys.stderr)
+        req.raise_for_status()
+        return
 
+    download_filepath = path+"_part"
+    with open(download_filepath, "wb") as file_binary:
         content_length = req.headers.get('Content-Length')
         total = int(content_length) if content_length is not None else None
         progress = tqdm(unit="B", total=total, unit_scale=True)
@@ -38,6 +40,8 @@ def http_get(url, path):
             if chunk: # filter out keep-alive new chunks
                 progress.update(len(chunk))
                 file_binary.write(chunk)
+
+    os.rename(download_filepath, path)
     progress.close()
 
 
